@@ -3,7 +3,9 @@
 #include "decomposition.hpp"
 #include <pybind11/pybind11.h>
 #include <pybind11/complex.h>
+#include <pybind11/stl.h>
 #include <pybind11/eigen.h>
+#include <pybind11/stl.h>
 
 namespace py = pybind11;
 using namespace pybind11::literals;
@@ -28,3 +30,10 @@ void bind_integrate_phase(py::module &m) {
         Integrate a phase function with a given source function
     )pbdoc");
 }
+
+void bind_grid_interpolate(py::module &m) {
+    m.def("grid_interpolate", grid_interpolate, 
+            "grid"_a, "data"_a, "pts"_a, "fill_value"_a=0, R"pbdoc(
+        Interpolate data on a grid
+    )pbdoc");
+}
