@@ -1,6 +1,7 @@
 from .sources import source, propagating_source, polarized_propagating_source, combined_source
 from .beams import beam, polarized_beam, reflected_beam
 from .dft_beams import dft_beam, scalar_dft_beam
+from .slm_beam import phase_only_slm
 
 from .plane_waves import plane_wave
 
@@ -8,3 +9,5 @@ from .common import (gaussian_beam, hermite_gaussian_beam, laguerre_gaussian_bea
                      bigaussian_beam, azimuthal_beam, radial_beam, shear_beam)
 
 from .point import point_dipole
+
+from .grid_interpolate import grid_interpolate_source
