@@ -7,5 +7,6 @@ from . import functions
 
 from .get_tmatrix import nfmds_solver, tmatrix_solvers
 from .common import (tmatrix_cylinder, tmatrix_spheroid, tmatrix_sphere, tmatrix_core_shell, 
-                     tmatrix_ellipsoid, tmatrix_square_prism, tmatrix_regular_prism)
+                     tmatrix_ellipsoid, tmatrix_square_prism, tmatrix_regular_prism,
+                     tmatrix_sphere_cluster)
 from .functions import tmatrix_reduce_lmax, rotate_tmatrix
