@@ -30,7 +30,7 @@ def test_plane_wave_rotation():
 
     lmax = 6
     R, THETA, PHI = miepy.coordinates.cart_to_sph(X, Y, Z)
-    p_src = source.structure([0,0,0], k, lmax)
+    p_src = source.structure([[0,0,0]], k, lmax)[0]
     Efunc = miepy.expand_E(p_src, k, mode=miepy.vsh_mode.incident)
 
     E2 = Efunc(R, THETA, PHI)
